
#include <LiquidCrystal_I2C.h>
#include <Wire.h>
#include <SoftWire.h>

int tDelay = 500;
int latchPin = 11;      // (11) ST_CP [RCK] on 74HC595
int clockPin = 9;      // (9) SH_CP [SCK] on 74HC595
int dataPin = 12;     // (12) DS [S1] on 74HC595
int buzzer = 3;

int ADXL345 = 0x53;

#define BLACK_BUTTON 2
#define BLUE_BUTTON 7
#define YELLOW_BUTTON 4
int blue_btn_state = 0;
int black_btn_state = 0;

byte leds = 0;
LiquidCrystal_I2C lcd(0x27,16,2);

float X_out, Y_out, Z_out;

// this first function to turn them off, from right to left (least significant)
// Adafruit_ADXL345_Unified accel = Adafruit_ADXL345_Unified();
void updateShiftRegister()
{
   digitalWrite(latchPin, LOW);
   shiftOut(dataPin, clockPin, LSBFIRST, leds); //LSBFIRST starts from the least significant Byte, that corresponds to 8th pinout 
   digitalWrite(latchPin, HIGH);
}
// this second function is to turn them off
void updateShiftRegister2() 
{ 
   digitalWrite(latchPin, HIGH);
   shiftOut(dataPin, clockPin, LSBFIRST, leds); //if we start with MSBFIRST in this function, then it would start from the most significant, that is the 1st pinout.
   digitalWrite(latchPin, LOW);
}

int landing_page_time = 0;

void setup() 
{
  pinMode(latchPin, OUTPUT);
  pinMode(dataPin, OUTPUT);  
  pinMode(clockPin, OUTPUT);
  pinMode(buzzer, OUTPUT);
  
  Wire.begin();

  // lcd
  lcd.begin();
  lcd.clear();
  
  // serial
  Serial.begin(9600);
  
  //buttons
  pinMode(BLACK_BUTTON, INPUT_PULLUP);
  pinMode(BLUE_BUTTON, INPUT_PULLUP);
  pinMode(YELLOW_BUTTON, INPUT_PULLUP);

  // acceloremeter
  // Set ADXL345 in measuring mode
  Wire.beginTransmission(ADXL345); // Start communicating with the device 
  Wire.write(0x2D); // Access/ talk to POWER_CTL Register - 0x2D
  // Enable measurement
  Wire.write(8); // (8dec -> 0000 1000 binary) Bit D3 High for measuring enable 
  Wire.endTransmission();
  delay(10);
}

void print_welcome_message() {
  lcd.setCursor(1, 0);
  lcd.print("Welcome");
  lcd.setCursor(9, 0);
  lcd.print("to");

  lcd.setCursor(1, 1);
  lcd.print("smart");
  lcd.setCursor(7, 1);
  lcd.print("roulette");
}

void read_accelerometer_data() {
  // === Read acceleromter data === //
  Wire.beginTransmission(ADXL345);
  Wire.write(0x32); // Start with register 0x32 (ACCEL_XOUT_H)
  Wire.endTransmission(false);
  Wire.requestFrom(ADXL345, 6, true); // Read 6 registers total, each axis value is stored in 2 registers
  X_out = ( Wire.read()| Wire.read() << 8); // X-axis value
  X_out = X_out/256; //For a range of +-2g, we need to divide the raw values by 256, according to the datasheet
  Y_out = ( Wire.read()| Wire.read() << 8); // Y-axis value
  Y_out = Y_out/256;
  Z_out = ( Wire.read()| Wire.read() << 8); // Z-axis value
  Z_out = Z_out/256;

  Serial.print("Xa= ");
  Serial.print(X_out);
  Serial.print("   Ya= ");
  Serial.print(Y_out);
  Serial.print("   Za= ");
  Serial.println(Z_out);
  delay(250);
}

int last_sum_coord = 0;
int sums[] = {10, 25, 45, 69, 80};
int save_bet = 0;
int blue_state = 0;
int black_state = 0;

void print_choose_sum_msg() {
  lcd.setCursor(0, 0);
  lcd.print("Choose Bet Sum:");
  if (last_sum_coord == 0) {
    lcd.setCursor(last_sum_coord, 1);
    lcd.print(sums[last_sum_coord]);
    save_bet = sums[last_sum_coord];
  }
  blue_state = digitalRead(BLUE_BUTTON);
  black_state = digitalRead(BLACK_BUTTON);
  if (blue_state == HIGH) {
    last_sum_coord += 3;
    lcd.setCursor(last_sum_coord, 1);
    lcd.print(sums[last_sum_coord]);
    save_bet = sums[last_sum_coord];
  }
  if (black_state == HIGH) {
    last_sum_coord -= 3;
    lcd.setCursor(last_sum_coord, 1);
    lcd.print(sums[last_sum_coord]);
    save_bet = sums[last_sum_coord];
  }
}

void loop() 
{
  //  leds = 0;
  // updateShiftRegister();
  
  if (landing_page_time <= 150) {
    print_welcome_message();
    if (landing_page_time == 150) {
      lcd.clear();
      landing_page_time++;
    } else {
      landing_page_time++;
    }
  } else {
    // lcd.clear();
    print_choose_sum_msg();
  }
  
  read_accelerometer_data();
  
  // SHIFT REGISTER
  for (int i = 0; i < 8; i++)
  {
    delay(tDelay);
    bitSet(leds, i); //bitset sets the byte of each led to on
    updateShiftRegister();    
  } 
 
  for (int i = 0; i < 8; i++)
  {
    bitClear(leds, i); //bitclear sets the byte of each led to off
    updateShiftRegister2();  
    delay(tDelay);
  }
  
  digitalWrite(buzzer, HIGH);
  delay(1000);
  digitalWrite(buzzer, LOW);
  delay(1000);
    
}


